@@ -124,6 +124,8 @@ def midday_ts(days_back: int = 0, ts: float = 0.) -> float:
     :param days_back:
     :return: ts in ms
     """
+    if ts > 5000000000:
+        ts /= 1000
     if not ts:
         today = datetime.datetime.now(gettz(os.environ['TZ']))
         yesterday = datetime.datetime(today.year, today.month, today.day, 12,
@@ -214,16 +216,16 @@ def age(dob: str) -> int:
     return today.year - dob.year - ((today.month, today.day) < (dob.month, dob.day))
 
 
-def ewma(y: float, y_0: float, std: float, alpha: float = 0.1) -> tuple:
+def ewma(y: float, y_0: float, std: float, span: int = 7) -> tuple:
     """
     Exponentialy weighted moving average
     :param y: new stat record
     :param y_0: current average value of a statistic
     :param std: current standard deviation of a statistic
-    :param alpha: parameter responsible for the smoothing
+    :param span: decay parameter
     :return: new average and std
     """
-
+    alpha = 2 / (span + 1)
     y_ = y_0
     var = std ** 2
     delta = y - y_
@@ -233,6 +235,25 @@ def ewma(y: float, y_0: float, std: float, alpha: float = 0.1) -> tuple:
     return y_, np.sqrt(var)
 
 
+def stats_update(count: int, mean: float, std: float, new_value: float):
+    """
+    Online update of the statistics
+    :param count: total number of points in the statistic
+    :param mean: current mean
+    :param std: current standard deviation
+    :param new_value: new value of the statistic
+    :return: new count, mean and standard deviation
+    """
+    var = std ** 2
+    M2 = var * count
+    count += 1
+    delta = new_value - mean
+    mean += delta / count
+    delta2 = new_value - mean
+    M2 += delta * delta2
+    return count, mean, np.sqrt(M2 / count)
+
+
 def check_dict_structure(dict_template: dict, dict_to_check: dict) -> dict:
     """
     Checks if all required fields are present, if not – initialises them
